==> haskell-hls-graph-2.1.0.0-51-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
key:                  hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  f1ce2c6110ee9fecfe56cbb5ab30c3c3
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    async-2.2.5-DWviBtrYTc7K8qRxzPsJC base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1
    exceptions-0.10.5 extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    filepath-1.4.2.2 focus-1.0.3.2-9UG6aWIJYQU1dpGJUMaXsH
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.7.1-BG7hudtjprP6S9eXaqWAZu
    list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn stm-2.5.1.0
    stm-containers-1.2.1.1-86Il8Zl0y3y9pRWBbzkv1j text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-2.1.0.0-81-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.1.0.0
visibility:           public
id:                   hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
key:                  hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  acc38dea9316554b74becce335f6f214
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E filepath-1.4.2.2
    focus-1.0.3.2-8hrsVfu9SCyGKwxAyYgRHl
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.7.1-9ZGAgHO9xNUAuSXWcLLmna
    list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP stm-2.5.1.0
    stm-containers-1.2.1.1-JkQzghCiirYSX2KXoZcs5 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
